RoutingEngine class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- info → EngineInfo
-
Engine identity and capabilities.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
calculateRoute(
RouteRequest request) → Future< RouteResult> - Calculate a route for the given request.
-
dispose(
) → Future< void> - Release resources.
-
isAvailable(
) → Future< bool> - Check if this engine is ready to serve requests.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited