ValhallaRoutingEngine class

Implemented types

Constructors

ValhallaRoutingEngine({String? baseUrl, Duration availabilityTimeout = const Duration(seconds: 3), Duration routeTimeout = const Duration(seconds: 15), Client? client})
ValhallaRoutingEngine.local({String host = 'localhost', int port = 8005, Duration availabilityTimeout = const Duration(seconds: 3), Duration routeTimeout = const Duration(seconds: 15), Client? client})

Properties

availabilityTimeout Duration
final
baseUrl String
final
hashCode int
The hash code for this object.
no setterinherited
info EngineInfo
Engine identity and capabilities.
no setteroverride
routeTimeout Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

calculateRoute(RouteRequest request) Future<RouteResult>
Calculate a route for the given request.
override
dispose() Future<void>
Release resources.
override
isAvailable() Future<bool>
Check if this engine is ready to serve requests.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited